from setuptools import setup, find_packages

setup(
    name='mbank_service',
    version='0.1.2',
    include_package_data=True,
    packages=find_packages(),
    license='TBD',
    author='Eldiyar Kandzhebaev',
    python_requires='>=3.9',
)
